==> oceanlab_api_client-0.0.11-py3-none-any.whl: oceanlab_api_client/models/tags_response_200_response.py <==
from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

from attrs import define, field

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.tags_response_200_response_result_item import TagsResponse200ResponseResultItem


T = TypeVar("T", bound="TagsResponse200Response")


@define
class TagsResponse200Response:
    """
    Attributes:
        result (Union[Unset, List['TagsResponse200ResponseResultItem']]):
    """

    result: Union[Unset, List["TagsResponse200ResponseResultItem"]] = UNSET
    additional_properties: Dict[str, Any] = field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        result: Union[Unset, List[Dict[str, Any]]] = UNSET
        if not isinstance(self.result, Unset):
            result = []
            for result_item_data in self.result:
                result_item = result_item_data.to_dict()

                result.append(result_item)

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if result is not UNSET:
            field_dict["result"] = result

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.tags_response_200_response_result_item import TagsResponse200ResponseResultItem

        d = src_dict.copy()
        result = []
        _result = d.pop("result", UNSET)
        for result_item_data in _result or []:
            result_item = TagsResponse200ResponseResultItem.from_dict(result_item_data)

            result.append(result_item)

        tags_response_200_response = cls(
            result=result,
        )

        tags_response_200_response.additional_properties = d
        return tags_response_200_response

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties

==> oceanlab_api_client-0.0.13-py3-none-any.whl: oceanlab_api_client/models/tags_response_200_response.py <==
from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.tags_response_200_response_result_item import TagsResponse200ResponseResultItem


T = TypeVar("T", bound="TagsResponse200Response")


@_attrs_define
class TagsResponse200Response:
    """
    Attributes:
        result (Union[Unset, List['TagsResponse200ResponseResultItem']]):
    """

    result: Union[Unset, List["TagsResponse200ResponseResultItem"]] = UNSET
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        result: Union[Unset, List[Dict[str, Any]]] = UNSET
        if not isinstance(self.result, Unset):
            result = []
            for result_item_data in self.result:
                result_item = result_item_data.to_dict()

                result.append(result_item)

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if result is not UNSET:
            field_dict["result"] = result

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.tags_response_200_response_result_item import TagsResponse200ResponseResultItem

        d = src_dict.copy()
        result = []
        _result = d.pop("result", UNSET)
        for result_item_data in _result or []:
            result_item = TagsResponse200ResponseResultItem.from_dict(result_item_data)

            result.append(result_item)

        tags_response_200_response = cls(
            result=result,
        )

        tags_response_200_response.additional_properties = d
        return tags_response_200_response

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties
